# IA23005UNO
Ruben Edgardo Iglesias Alfaro IA23005
Examen Corto de la Materia Calculo Numerico para Desarollo de Aplicaciones
GT01
Librería para resolver sistemas de ecuaciones lineales y no lineales.

## Métodos implementados

- Eliminación de Gauss
- Gauss-Jordan
- Crammer
- Descomposición LU
- Jacobi
- Gauss-Seidel
- Bisección

## Instalación local, esto si desea usarlo en forma local
python -m pip install -e .

## Instalación por libreria

```bash
pip install IA23005UNO

